<?php

use Tygh\Registry;
use Tygh\Addons\RusTaxes\TaxType;
use Tygh\Addons\SwBifitOnline\Logs;
use Tygh\Addons\SwBifitOnline\Client;
use Tygh\Addons\SwBifitOnline\Exception;
use Tygh\Addons\SwBifitOnline\CheckContent;
use Tygh\Addons\SwBifitOnline\Processing;

if (!defined('BOOTSTRAP')) { die('Access denied'); }

if ($mode === 'update_receipt') {
    fn_sw_bifit_online__update_receipts_statuses();
    return array(CONTROLLER_STATUS_OK,'sw_bifit_online.receipts');
}

if ($mode === 'receipts') {

    $receipts = new Client();
    /** @var \Tygh\SmartyEngine\Core $view */
    $view = Tygh::$app['view'];

    $search = $conditions = array();
    $limit = null;
    $page = isset($_REQUEST['page']) ? (int) $_REQUEST['page'] : 1;

    if (isset($_REQUEST['items_per_page'])) {
        $limit = (int) $_REQUEST['items_per_page'];
    }

    if (!$limit) {
        $limit = (int) Registry::ifGet('settings.Appearance.admin_elements_per_page', 10);
    }

    if (isset($_REQUEST['search']['type']) && !empty($_REQUEST['search']['type'])) {
        $search['type'] = $conditions['type'] = $_REQUEST['search']['type'];
    }

    if (isset($_REQUEST['search']['status']) && !empty($_REQUEST['search']['status'])) {
        $search['status'] = $conditions['status'] = $_REQUEST['search']['status'];
    }

    if (isset($_REQUEST['receipts_period'])) {
        $search['receipts_period'] = $_REQUEST['receipts_period'];
        $search['receipts_time_from'] = $_REQUEST['receipts_time_from'];
        $search['receipts_time_to'] = $_REQUEST['receipts_time_to'];

        list($time_from, $time_to) = fn_create_periods(array(
            'period' => $_REQUEST['receipts_period'],
            'time_from' => $_REQUEST['receipts_time_from'],
            'time_to' => $_REQUEST['receipts_time_to']
        ));

        $conditions[] = array('timestamp', '>=', $time_from);
        $conditions[] = array('timestamp', '<=', $time_to);
    }

    $total_items = $receipts->count($conditions);

    $page = db_get_valid_page($page, $limit, $total_items);
    $offset = ($page - 1) * $limit;

    $receipts = $receipts->search($conditions, $limit, $offset);

    $search = array_merge($search, array(
        'items_per_page' => $limit,
        'total_items' => $total_items,
        'page' => $page
    ));
    
    $view->assign('receipts', $receipts);
    $view->assign('search', $search);
    $view->assign('statuses', array(
        //'WAIT' => 'WAIT',
        'DONE' => 'DONE',
        'FAIL' => 'FAIL'
    ));
    
    $types = fn_get_schema('sw_bifit_online', 'ReceiptType');
    $view->assign('types', $types);
    
} elseif ($mode === 'logs') {

    $Logs = new Logs();
    /** @var \Tygh\SmartyEngine\Core $view */
    $view = Tygh::$app['view'];

    $search = $conditions = array();
    $limit = null;
    $page = isset($_REQUEST['page']) ? (int) $_REQUEST['page'] : 1;

    if (isset($_REQUEST['items_per_page'])) {
        $limit = (int) $_REQUEST['items_per_page'];
    }

    if (!$limit) {
        $limit = (int) Registry::ifGet('settings.Appearance.admin_elements_per_page', 10);
    }

    if (isset($_REQUEST['search']['status']) && (!empty($_REQUEST['search']['status']) || $_REQUEST['search']['status'] == '0')) {
        $search['status'] = $conditions['status'] = $_REQUEST['search']['status'];
    }
    
  

    if (isset($_REQUEST['logs_period'])) {
        $search['logs_period'] = $_REQUEST['logs_period'];
        $search['logs_time_from'] = $_REQUEST['logs_time_from'];
        $search['logs_time_to'] = $_REQUEST['logs_time_to'];

        list($time_from, $time_to) = fn_create_periods(array(
            'period' => $_REQUEST['logs_period'],
            'time_from' => $_REQUEST['logs_time_from'],
            'time_to' => $_REQUEST['logs_time_to']
        ));

        $conditions[] = array('timestamp', '>=', $time_from);
        $conditions[] = array('timestamp', '<=', $time_to);
    }

    $total_items = $Logs->count($conditions);

    $page = db_get_valid_page($page, $limit, $total_items);
    $offset = ($page - 1) * $limit;

    $logs = $Logs->search($conditions, $limit, $offset);

    $search = array_merge($search, array(
        'items_per_page' => $limit,
        'total_items' => $total_items,
        'page' => $page
    ));

    $view->assign('logs', $logs);
    $view->assign('search', $search);
    
    $statuses = array(
        '1' => __("sw_bifit_online.logs.success"),
        '0' => __("sw_bifit_online.logs.fail")
    );
    
    $view->assign('statuses', $statuses);

}

/*
* Test connect
* auth()
*/

if ($mode === 'test_connect') {
    
    $client = new Client();
    $e = new Exception();

    $settings = $_REQUEST;

    $res = $client->getToken();
    
    if(isset($res['access_token']) && !empty($res['access_token'])){
        fn_set_notification('N', __('notice'), __('sw_bifit_online.test_connect_res'));
    }else{
        list($error,$message) = $e->getMessage($res);
        fn_set_notification('E', __('error'), $message);
    }

    exit;
}


/*
* TEST DEV
*/

if ($mode === 'check_content') {
    
    exit; //UNCOMMENT
    
    $client = new Client();
    $e = new Exception();
    
    //$token = $client->getToken();
    $token = 123;
    $addon_settings = Registry::get('addons.sw_bifit_online');
    
    $CheckContent = new CheckContent($token, $addon_settings);
    
    $order = fn_get_order_info(111);
    
    //Формирование чека
    $check_data = $CheckContent->getCheckContent($order);
    
    fn_print_r($check_data, $order);
    
    exit;
}

if ($mode === 'send') {
    $client = new Client();
    $e = new Exception();
    
    $token = $client->getToken();
    $addon_settings = Registry::get('addons.sw_bifit_online');
    
   
    //Формирование чека
    $CheckContent = new CheckContent($token, $addon_settings);
    $order = fn_get_order_info(111);
    $check_data = $CheckContent->getCheckContent($order);
 
    //Отправка чека
    $processing = new Processing($token, $addon_settings);
    $check_id = $processing->send($check_data, $order);
    
    fn_print_r($CheckContent, $check_id);
    
    exit;
}

if($mode == 'get_doc'){
    
    $doc_id = 1539;
    $order_id = 111;
    
    $client = new Client();
    $res = $client->get_document($doc_id);
    
   
    
    fn_sw_bifit_online_add_check_status($res, $order_id);
    fn_sw_bifit_online_add_document_data($res, $order_id);
    
    exit;
}

